# server
workspace_id = 'wsp46bf41a21d09c07f'
# core 1
core_id_1 = 'cre488fee3799074eee'
view_id_1 = 'viw488ff6c68905750d'
table_id_1 = 'tbl488ff16957075d9d'
column_id_1 = 'col48907ad50d8b487b'
column_name_1 = 'col_name1'
view_name_1 = 'viewname'
row_id_1 = 'row489068979504c18c'
core_name_1 = 'test_pysdk'

# # local
# workspace_id = 'wspb59083e8e085e9af'
# # core 1
# core_id_1 = 'creb59083ec830851cc'
# view_id_1 = 'viwb59083f069813b22'
# table_id_1 = 'tblb59083ee9505054d'
# column_id_1 = 'colb59084087b8259b7'
# column_name_1 = 'col_name1'
# view_name_1 = 'viewname'
# row_id_1 = 'rowb590840785034627'
